pub struct ExtendedIrmaRequest {
pub validity: Option<u64>,
pub timeout: Option<u64>,
pub callback_url: Option<String>,
pub request: IrmaRequest,
}Expand description
An IRMA request extended with extra information for the server on how to execute it. (Note: this interface is unstable, and might change significantly in the future)
Fields
validity: Option<u64>How long a session result JWT should be valid once requested, in seconds
timeout: Option<u64>How long the session remains available for an IRMA client to connect to
callback_url: Option<String>URL on which to recieve updates as the session status changes
request: IrmaRequestInner request